/*
   Tables.c : Data tables for the Linux Trace Toolkit.
   Copyright (C) 1999, 2000 Karim Yaghmour (karym@opersys.com).
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   History : 
     K.Y., 31/05/2000, Added generalized support for multiple tables
     K.Y., 29/10/99, Initial typing.
*/

#include "Tables.h"
#include "LinuxEvents.h"
#include "LinuxTables.h"
#if SUPP_RTAI
#include "RTAIEvents.h"
#include "RTAITables.h"
#endif /* SUPP_RTAI */

/* Initial values of structures */
int**   EventStructSize = (int**)  &LinuxEventStructSize;
char**  EventID         = (char**)  LinuxEventID;
char**  SyscallID       = (char**)  LinuxSyscallID;
char**  TrapID          = (char**)  LinuxTrapID;

/* We don't know the type of trace before hand. Therefore, use the table that includes
   the most events possible. */
#if SUPP_RTAI
int     MaxEventID      = TRACE_RTAI_MAX;
char**  EventOT         = (char**)  RTAIEventOT;
#else
int     MaxEventID      = TRACE_MAX;
char**  EventOT         = (char**)  LinuxEventOT;
#endif

/******************************************************************
 * Function :
 *    TSetTraceType()
 * Description :
 *    Sets the type of trace being analyzed so that the event related
 *    tables match the type of trace analyzed.
 * Parameters :
 *    pmTraceDataFile, File containing the raw trace data.
 *    pmTraceDB, The event database to be built.
 * Return values :
 *    NONE
 * History :
 *    K.Y., 31/05/2000, Initial typing.
 * Note :
 ******************************************************************/
void TSetTraceType(int pmTraceType)
{
  /* Depending on the type of trace */
  switch(pmTraceType)
    {
    case TRACE_TYPE_VANILLA_LINUX:
#if 0
      printf("TraceToolkit: Trace is vanilla linux kernel \n");
#endif

      /* Set everything to reflect Linux' tables */
      MaxEventID      = TRACE_MAX;
      EventStructSize = (int**) &LinuxEventStructSize;
      EventID         = (char**) LinuxEventID;
      EventOT         = (char**) LinuxEventOT;
      SyscallID       = (char**) LinuxSyscallID;
      TrapID          = (char**) LinuxTrapID;
      break;

#if SUPP_RTAI
    case TRACE_TYPE_RTAI_LINUX:
#if 0
      printf("TraceToolkit: Trace contains RTAI data \n");
#endif

      /* Use RTAI values */
      MaxEventID      = TRACE_RTAI_MAX;
      EventStructSize = (int**) &RTAIEventStructSize;
      EventID         = (char**) RTAIEventID;
      EventOT         = (char**) RTAIEventOT;

      /* The syscall IDs and trap IDs remain Linux' */
      SyscallID       = (char**) LinuxSyscallID;
      TrapID          = (char**) LinuxTrapID;
      break;
#endif /* SUPP_RTAI */

    default:
#if 1
      printf("TraceToolkit: Unknown trace type %d \n", pmTraceType);
#endif
      exit(1);
      break;
    }
}
